This project is being dusted off
================================

| This project was transferred to Brodderick Rodriguez in February 2020 who will oversee its development from here on out.
| A big thanks to Russell for his original authorship of this project.


Cassowary
=========

A pure Python implementation of the `Cassowary constraint-solving algorithm`_.
Cassowary is the algorithm that forms the core of the OS X and iOS visual
layout mechanism.

.. _Cassowary constraint-solving algorithm: http://www.cs.washington.edu/research/constraints/cassowary/

Quickstart
----------

Cassowary is compatible with both Python 2 or Python 3. To install Cassowary
in your virtualenv, run::

    $ pip install cassowary

Then, in your Python code, you can create and solve constraint systems. See
`the documentation`_ for examples of what this looks like in
practice.

.. _the documentation: https://cassowary.readthedocs.io/en/latest/topics/examples.html

Documentation
-------------

Documentation for Cassowary can be found on `Read The Docs`_.

Community
---------
| Notice: Cassowary is no longer part of the BeeWare suite.
| You can talk to the community through:

 * Tweet Brodderick on Twitter: `@teamskynet_`_


Contributing
------------

If you experience problems with Cassowary, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.


Project Administration
----------------------
| This project was transferred to Brodderick Rodriguez in February 2020 who will continue to oversee its development from here on out.
| Russell Keith-Magee is the original author of this work. A big thanks to him for his work! Check out `Russell's GitHub`_.


.. _Russell's GitHub: https://github.com/freakboy3742
.. _@teamskynet_: https://twitter.com/teamskynet_
.. _homepage: http://brodderick.com/projects/cassowary
.. _Read The Docs: https://cassowary.readthedocs.io

.. _log them on Github: https://github.com/brodderickrodriguez/cassowary/issues
.. _fork the code: https://github.com/brodderickrodriguez/cassowary
.. _submit a pull request: https://github.com/brodderickrodriguez/cassowary/pulls
